@@ -19,11 +19,13 @@ import (
 	aos "github.com/aquasecurity/trivy/pkg/fanal/analyzer/os"
 	"github.com/aquasecurity/trivy/pkg/fanal/log"
 	"github.com/aquasecurity/trivy/pkg/fanal/types"
+	"github.com/aquasecurity/trivy/pkg/mapfs"
+	"github.com/aquasecurity/trivy/pkg/syncx"
 )
 
 var (
-	analyzers       = map[Type]analyzer{}
-	configAnalyzers = map[Type]configAnalyzer{}
+	analyzers     = map[Type]analyzer{}
+	postAnalyzers = map[Type]postAnalyzerInitialize{}
 
 	// ErrUnknownOS occurs when unknown OS is analyzed.
 	ErrUnknownOS = xerrors.New("unknown OS")
@@ -40,6 +42,7 @@ var (
 // AnalyzerOptions is used to initialize analyzers
 type AnalyzerOptions struct {
 	Group                Group
+	Slow                 bool
 	FilePatterns         []string
 	DisabledAnalyzers    []Type
 	SecretScannerOption  SecretScannerOption
@@ -71,11 +74,11 @@ type analyzer interface {
 	Required(filePath string, info os.FileInfo) bool
 }
 
-type configAnalyzer interface {
+type PostAnalyzer interface {
 	Type() Type
 	Version() int
-	Analyze(targetOS types.OS, content []byte) (types.Packages, error)
-	Required(osFound types.OS) bool
+	PostAnalyze(ctx context.Context, input PostAnalysisInput) (*AnalysisResult, error)
+	Required(filePath string, info os.FileInfo) bool
 }
 
 ////////////////////
@@ -87,23 +90,26 @@ type Group string
 const GroupBuiltin Group = "builtin"
 
 func RegisterAnalyzer(analyzer analyzer) {
+	if _, ok := analyzers[analyzer.Type()]; ok {
+		log.Logger.Fatalf("analyzer %s is registered twice", analyzer.Type())
+	}
 	analyzers[analyzer.Type()] = analyzer
 }
 
+type postAnalyzerInitialize func(options AnalyzerOptions) (PostAnalyzer, error)
+
+func RegisterPostAnalyzer(t Type, initializer postAnalyzerInitialize) {
+	if _, ok := postAnalyzers[t]; ok {
+		log.Logger.Fatalf("analyzer %s is registered twice", t)
+	}
+	postAnalyzers[t] = initializer
+}
+
 // DeregisterAnalyzer is mainly for testing
 func DeregisterAnalyzer(t Type) {
 	delete(analyzers, t)
 }
 
-func RegisterConfigAnalyzer(analyzer configAnalyzer) {
-	configAnalyzers[analyzer.Type()] = analyzer
-}
-
-// DeregisterConfigAnalyzer is mainly for testing
-func DeregisterConfigAnalyzer(t Type) {
-	delete(configAnalyzers, t)
-}
-
 // CustomGroup returns a group name for custom analyzers
 // This is mainly intended to be used in Aqua products.
 type CustomGroup interface {
@@ -113,9 +119,9 @@ type CustomGroup interface {
 type Opener func() (dio.ReadSeekCloserAt, error)
 
 type AnalyzerGroup struct {
-	analyzers       []analyzer
-	configAnalyzers []configAnalyzer
-	filePatterns    map[Type][]*regexp.Regexp
+	analyzers     []analyzer
+	postAnalyzers []PostAnalyzer
+	filePatterns  map[Type][]*regexp.Regexp
 }
 
 ///////////////////////////
@@ -131,6 +137,11 @@ type AnalysisInput struct {
 	Options AnalysisOptions
 }
 
+type PostAnalysisInput struct {
+	FS      fs.FS
+	Options AnalysisOptions
+}
+
 type AnalysisOptions struct {
 	Offline bool
 }
@@ -353,32 +364,39 @@ func NewAnalyzerGroup(opt AnalyzerOptions) (AnalyzerGroup, error) {
 		group.analyzers = append(group.analyzers, a)
 	}
 
-	for analyzerType, a := range configAnalyzers {
-		if slices.Contains(opt.DisabledAnalyzers, analyzerType) {
+	for analyzerType, init := range postAnalyzers {
+		a, err := init(opt)
+		if err != nil {
+			return AnalyzerGroup{}, xerrors.Errorf("post-analyzer init error: %w", err)
+		}
+		if !belongToGroup(groupName, analyzerType, opt.DisabledAnalyzers, a) {
 			continue
 		}
-		group.configAnalyzers = append(group.configAnalyzers, a)
+		group.postAnalyzers = append(group.postAnalyzers, a)
 	}
 
 	return group, nil
 }
 
-// AnalyzerVersions returns analyzer version identifier used for cache keys.
-func (ag AnalyzerGroup) AnalyzerVersions() map[string]int {
-	versions := map[string]int{}
-	for _, a := range ag.analyzers {
-		versions[string(a.Type())] = a.Version()
-	}
-	return versions
+type Versions struct {
+	Analyzers     map[string]int
+	PostAnalyzers map[string]int
 }
 
-// ImageConfigAnalyzerVersions returns analyzer version identifier used for cache keys.
-func (ag AnalyzerGroup) ImageConfigAnalyzerVersions() map[string]int {
-	versions := map[string]int{}
-	for _, ca := range ag.configAnalyzers {
-		versions[string(ca.Type())] = ca.Version()
+// AnalyzerVersions returns analyzer version identifier used for cache keys.
+func (ag AnalyzerGroup) AnalyzerVersions() Versions {
+	analyzerVersions := map[string]int{}
+	for _, a := range ag.analyzers {
+		analyzerVersions[string(a.Type())] = a.Version()
+	}
+	postAnalyzerVersions := map[string]int{}
+	for _, a := range ag.postAnalyzers {
+		postAnalyzerVersions[string(a.Type())] = a.Version()
+	}
+	return Versions{
+		Analyzers:     analyzerVersions,
+		PostAnalyzers: postAnalyzerVersions,
 	}
-	return versions
 }
 
 func (ag AnalyzerGroup) AnalyzeFile(ctx context.Context, wg *sync.WaitGroup, limit *semaphore.Weighted, result *AnalysisResult,
@@ -424,30 +442,47 @@ func (ag AnalyzerGroup) AnalyzeFile(ctx context.Context, wg *sync.WaitGroup, lim
 				Content:  rc,
 				Options:  opts,
 			})
-			if err != nil && !xerrors.Is(err, aos.AnalyzeOSError) {
+			if err != nil && !errors.Is(err, aos.AnalyzeOSError) {
 				log.Logger.Debugf("Analysis error: %s", err)
 				return
 			}
-			if ret != nil {
-				result.Merge(ret)
-			}
+			result.Merge(ret)
 		}(a, rc)
 	}
 
 	return nil
 }
 
-func (ag AnalyzerGroup) AnalyzeImageConfig(targetOS types.OS, configBlob []byte) []types.Package {
-	for _, d := range ag.configAnalyzers {
-		if !d.Required(targetOS) {
+func (ag AnalyzerGroup) RequiredPostAnalyzers(filePath string, info os.FileInfo) []Type {
+	var postAnalyzerTypes []Type
+	for _, a := range ag.postAnalyzers {
+		if a.Required(filePath, info) {
+			postAnalyzerTypes = append(postAnalyzerTypes, a.Type())
+		}
+	}
+	return postAnalyzerTypes
+}
+
+func (ag AnalyzerGroup) PostAnalyze(ctx context.Context, files *syncx.Map[Type, *mapfs.FS], result *AnalysisResult, opts AnalysisOptions) error {
+	for _, a := range ag.postAnalyzers {
+		fsys, ok := files.Load(a.Type())
+		if !ok {
 			continue
 		}
 
-		pkgs, err := d.Analyze(targetOS, configBlob)
+		filteredFS, err := fsys.Filter(result.SystemInstalledFiles)
 		if err != nil {
-			continue
+			return xerrors.Errorf("unable to filter filesystem: %w", err)
 		}
-		return pkgs
+
+		res, err := a.PostAnalyze(ctx, PostAnalysisInput{
+			FS:      filteredFS,
+			Options: opts,
+		})
+		if err != nil {
+			return xerrors.Errorf("post analysis error: %w", err)
+		}
+		result.Merge(res)
 	}
 	return nil
 }
