@@ -4,7 +4,6 @@ type HandlerType string
 
 const (
 	SystemFileFilteringPostHandler HandlerType = "system-file-filter"
-	GoModMergePostHandler          HandlerType = "go-mod-merge"
 	MisconfPostHandler             HandlerType = "misconf"
 	UnpackagedPostHandler          HandlerType = "unpackaged"
 
@@ -12,7 +11,6 @@ const (
 	// Otherwise, other handlers need to process unnecessary files.
 	SystemFileFilteringPostHandlerPriority = 100
 
-	GoModMergePostHandlerPriority = 50
 	MisconfPostHandlerPriority    = 50
 	UnpackagedPostHandlerPriority = 50
 )
