@@ -8,18 +8,18 @@ import (
 	"path/filepath"
 	"time"
 
-	"github.com/aquasecurity/trivy/pkg/oci"
-
 	"github.com/open-policy-agent/opa/bundle"
-	"golang.org/x/xerrors"
-	"k8s.io/utils/clock"
 
 	"github.com/aquasecurity/trivy/pkg/log"
+	"github.com/aquasecurity/trivy/pkg/oci"
+
+	"golang.org/x/xerrors"
+	"k8s.io/utils/clock"
 )
 
 const (
-	bundleVersion    = 1
-	bundleRepository = "ghcr.io/aquasecurity/appshield"
+	bundleVersion    = 0 // Latest released MAJOR version for defsec
+	bundleRepository = "ghcr.io/aquasecurity/defsec"
 	policyMediaType  = "application/vnd.cncf.openpolicyagent.layer.v1.tar+gzip"
 	updateInterval   = 24 * time.Hour
 )
@@ -29,9 +29,6 @@ type options struct {
 	clock    clock.Clock
 }
 
-// Option is a functional option
-type Option func(*options)
-
 // WithOCIArtifact takes an OCI artifact
 func WithOCIArtifact(art *oci.Artifact) Option {
 	return func(opts *options) {
@@ -46,17 +43,21 @@ func WithClock(clock clock.Clock) Option {
 	}
 }
 
-// Metadata holds default policy metadata
-type Metadata struct {
-	Digest       string
-	DownloadedAt time.Time
-}
+// Option is a functional option
+type Option func(*options)
 
 // Client implements policy operations
 type Client struct {
 	*options
 	policyDir string
 	quiet     bool
+	insecure  bool
+}
+
+// Metadata holds default policy metadata
+type Metadata struct {
+	Digest       string
+	DownloadedAt time.Time
 }
 
 // NewClient is the factory method for policy client
@@ -76,12 +77,50 @@ func NewClient(cacheDir string, quiet bool, opts ...Option) (*Client, error) {
 	}, nil
 }
 
+func (c *Client) populateOCIArtifact() error {
+	if c.artifact == nil {
+		repo := fmt.Sprintf("%s:%d", bundleRepository, bundleVersion)
+		art, err := oci.NewArtifact(repo, policyMediaType, c.quiet, c.insecure)
+		if err != nil {
+			return xerrors.Errorf("OCI artifact error: %w", err)
+		}
+		c.artifact = art
+	}
+	return nil
+}
+
+// DownloadBuiltinPolicies download default policies from GitHub Pages
+func (c *Client) DownloadBuiltinPolicies(ctx context.Context) error {
+	if err := c.populateOCIArtifact(); err != nil {
+		return xerrors.Errorf("OPA bundle error: %w", err)
+	}
+
+	dst := c.contentDir()
+	if err := c.artifact.Download(ctx, dst); err != nil {
+		return xerrors.Errorf("download error: %w", err)
+	}
+
+	digest, err := c.artifact.Digest()
+	if err != nil {
+		return xerrors.Errorf("digest error: %w", err)
+	}
+	log.Logger.Debugf("Digest of the built-in policies: %s", digest)
+
+	// Update metadata.json with the new digest and the current date
+	if err = c.updateMetadata(digest, c.clock.Now()); err != nil {
+		return xerrors.Errorf("unable to update the policy metadata: %w", err)
+	}
+
+	return nil
+}
+
 // LoadBuiltinPolicies loads default policies
 func (c *Client) LoadBuiltinPolicies() ([]string, error) {
 	f, err := os.Open(c.manifestPath())
 	if err != nil {
 		return nil, xerrors.Errorf("manifest file open error (%s): %w", c.manifestPath(), err)
 	}
+	defer f.Close()
 
 	var manifest bundle.Manifest
 	if err = json.NewDecoder(f).Decode(&manifest); err != nil {
@@ -109,6 +148,7 @@ func (c *Client) NeedsUpdate() (bool, error) {
 		log.Logger.Debugf("Failed to open the policy metadata: %s", err)
 		return true, nil
 	}
+	defer f.Close()
 
 	var meta Metadata
 	if err = json.NewDecoder(f).Decode(&meta); err != nil {
@@ -144,41 +184,16 @@ func (c *Client) NeedsUpdate() (bool, error) {
 	return false, nil
 }
 
-func (c *Client) populateOCIArtifact() error {
-	if c.artifact == nil {
-		repo := fmt.Sprintf("%s:%d", bundleRepository, bundleVersion)
-		art, err := oci.NewArtifact(repo, policyMediaType, c.quiet)
-		if err != nil {
-			return xerrors.Errorf("OCI artifact error: %w", err)
-		}
-		c.artifact = art
-	}
-	return nil
+func (c *Client) contentDir() string {
+	return filepath.Join(c.policyDir, "content")
 }
 
-// DownloadBuiltinPolicies download default policies from GitHub Pages
-func (c *Client) DownloadBuiltinPolicies(ctx context.Context) error {
-	if err := c.populateOCIArtifact(); err != nil {
-		return xerrors.Errorf("OPA bundle error: %w", err)
-	}
+func (c *Client) metadataPath() string {
+	return filepath.Join(c.policyDir, "metadata.json")
+}
 
-	dst := c.contentDir()
-	if err := c.artifact.Download(ctx, dst); err != nil {
-		return xerrors.Errorf("download error: %w", err)
-	}
-
-	digest, err := c.artifact.Digest()
-	if err != nil {
-		return xerrors.Errorf("digest error: %w", err)
-	}
-	log.Logger.Debugf("Digest of the built-in policies: %s", digest)
-
-	// Update metadata.json with the new digest and the current date
-	if err = c.updateMetadata(digest, c.clock.Now()); err != nil {
-		return xerrors.Errorf("unable to update the policy metadata: %w", err)
-	}
-
-	return nil
+func (c *Client) manifestPath() string {
+	return filepath.Join(c.contentDir(), bundle.ManifestExt)
 }
 
 func (c *Client) updateMetadata(digest string, now time.Time) error {
@@ -199,15 +214,3 @@ func (c *Client) updateMetadata(digest string, now time.Time) error {
 
 	return nil
 }
-
-func (c *Client) contentDir() string {
-	return filepath.Join(c.policyDir, "content")
-}
-
-func (c *Client) metadataPath() string {
-	return filepath.Join(c.policyDir, "metadata.json")
-}
-
-func (c *Client) manifestPath() string {
-	return filepath.Join(c.contentDir(), bundle.ManifestExt)
-}
