@@ -5,16 +5,17 @@ import (
 	"strings"
 	"sync"
 
-	"github.com/aquasecurity/trivy/pkg/report/predicate"
-	"github.com/aquasecurity/trivy/pkg/report/table"
-
 	"golang.org/x/xerrors"
 
 	dbTypes "github.com/aquasecurity/trivy-db/pkg/types"
+	cr "github.com/aquasecurity/trivy/pkg/compliance/report"
+	"github.com/aquasecurity/trivy/pkg/compliance/spec"
 	"github.com/aquasecurity/trivy/pkg/log"
 	"github.com/aquasecurity/trivy/pkg/report/cyclonedx"
 	"github.com/aquasecurity/trivy/pkg/report/github"
+	"github.com/aquasecurity/trivy/pkg/report/predicate"
 	"github.com/aquasecurity/trivy/pkg/report/spdx"
+	"github.com/aquasecurity/trivy/pkg/report/table"
 	"github.com/aquasecurity/trivy/pkg/types"
 )
 
@@ -33,21 +34,38 @@ const (
 )
 
 var (
-	SupportedFormats = []string{FormatTable, FormatJSON, FormatTemplate, FormatSarif, FormatCycloneDX, FormatSPDX, FormatSPDXJSON, FormatGitHub, FormatCosignVuln}
+	SupportedFormats = []string{
+		FormatTable,
+		FormatJSON,
+		FormatTemplate,
+		FormatSarif,
+		FormatCycloneDX,
+		FormatSPDX,
+		FormatSPDXJSON,
+		FormatGitHub,
+		FormatCosignVuln,
+	}
 )
 
 var (
-	SupportedSBOMFormats = []string{FormatCycloneDX, FormatSPDX, FormatSPDXJSON, FormatGitHub}
+	SupportedSBOMFormats = []string{
+		FormatCycloneDX,
+		FormatSPDX,
+		FormatSPDXJSON,
+		FormatGitHub,
+	}
 )
 
 type Option struct {
 	AppVersion string
 
 	Format         string
+	Report         string
 	Output         io.Writer
 	Tree           bool
 	Severities     []dbTypes.Severity
 	OutputTemplate string
+	Compliance     spec.ComplianceSpec
 
 	// For misconfigurations
 	IncludeNonFailures bool
@@ -60,6 +78,11 @@ type Option struct {
 
 // Write writes the result to output, format as passed in argument
 func Write(report types.Report, option Option) error {
+	// Compliance report
+	if option.Compliance.Spec.ID != "" {
+		return complianceWrite(report, option)
+	}
+
 	var writer Writer
 	switch option.Format {
 	case FormatTable:
@@ -76,7 +99,10 @@ func Write(report types.Report, option Option) error {
 	case FormatJSON:
 		writer = &JSONWriter{Output: option.Output}
 	case FormatGitHub:
-		writer = &github.Writer{Output: option.Output, Version: option.AppVersion}
+		writer = &github.Writer{
+			Output:  option.Output,
+			Version: option.AppVersion,
+		}
 	case FormatCycloneDX:
 		// TODO: support xml format option with cyclonedx writer
 		writer = cyclonedx.NewWriter(option.Output, option.AppVersion)
@@ -86,7 +112,10 @@ func Write(report types.Report, option Option) error {
 		// We keep `sarif.tpl` template working for backward compatibility for a while.
 		if strings.HasPrefix(option.OutputTemplate, "@") && strings.HasSuffix(option.OutputTemplate, "sarif.tpl") {
 			log.Logger.Warn("Using `--template sarif.tpl` is deprecated. Please migrate to `--format sarif`. See https://github.com/aquasecurity/trivy/discussions/1571")
-			writer = SarifWriter{Output: option.Output, Version: option.AppVersion}
+			writer = SarifWriter{
+				Output:  option.Output,
+				Version: option.AppVersion,
+			}
 			break
 		}
 		var err error
@@ -94,7 +123,10 @@ func Write(report types.Report, option Option) error {
 			return xerrors.Errorf("failed to initialize template writer: %w", err)
 		}
 	case FormatSarif:
-		writer = SarifWriter{Output: option.Output, Version: option.AppVersion}
+		writer = SarifWriter{
+			Output:  option.Output,
+			Version: option.AppVersion,
+		}
 	case FormatCosignVuln:
 		writer = predicate.NewVulnWriter(option.Output, option.AppVersion)
 	default:
@@ -107,6 +139,19 @@ func Write(report types.Report, option Option) error {
 	return nil
 }
 
+func complianceWrite(report types.Report, opt Option) error {
+	complianceReport, err := cr.BuildComplianceReport([]types.Results{report.Results}, opt.Compliance)
+	if err != nil {
+		return xerrors.Errorf("compliance report build error: %w", err)
+	}
+	return cr.Write(complianceReport, cr.Option{
+		Format:     opt.Format,
+		Report:     opt.Report,
+		Output:     opt.Output,
+		Severities: opt.Severities,
+	})
+}
+
 // Writer defines the result write operation
 type Writer interface {
 	Write(types.Report) error
