@@ -1,8 +1,8 @@
 package types
 
 import (
-	ftypes "github.com/aquasecurity/fanal/types"
 	"github.com/aquasecurity/trivy-db/pkg/types"
+	ftypes "github.com/aquasecurity/trivy/pkg/fanal/types"
 )
 
 // DetectedVulnerability holds the information of detected vulnerabilities
@@ -17,6 +17,7 @@ type DetectedVulnerability struct {
 	Layer            ftypes.Layer   `json:",omitempty"`
 	SeveritySource   types.SourceID `json:",omitempty"`
 	PrimaryURL       string         `json:",omitempty"`
+	Ref              string         `json:",omitempty"`
 
 	// DataSource holds where the advisory comes from
 	DataSource *types.DataSource `json:",omitempty"`
@@ -28,13 +29,18 @@ type DetectedVulnerability struct {
 	types.Vulnerability
 }
 
+// GetID retrun Vulnerability ID
+func (vuln *DetectedVulnerability) GetID() string {
+	return vuln.VulnerabilityID
+}
+
 // BySeverity implements sort.Interface based on the Severity field.
 type BySeverity []DetectedVulnerability
 
 // Len returns the length of DetectedVulnerabilities
 func (v BySeverity) Len() int { return len(v) }
 
-// Less compares 2 DetectedVulnerabilities based on package name, severity and vulnerabilityID
+// Less compares 2 DetectedVulnerabilities based on package name, severity, vulnerabilityID and package path
 func (v BySeverity) Less(i, j int) bool {
 	if v[i].PkgName != v[j].PkgName {
 		return v[i].PkgName < v[j].PkgName
@@ -47,7 +53,10 @@ func (v BySeverity) Less(i, j int) bool {
 	if ret != 0 {
 		return ret > 0
 	}
-	return v[i].VulnerabilityID < v[j].VulnerabilityID
+	if v[i].VulnerabilityID != v[j].VulnerabilityID {
+		return v[i].VulnerabilityID < v[j].VulnerabilityID
+	}
+	return v[i].PkgPath < v[j].PkgPath
 }
 
 // Swap swaps 2 vulnerability
